@@ -7,75 +7,122 @@ use warnings;
 require DynaLoader;
 our @ISA = qw(DynaLoader);
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 # use all files under Ogre/ - probably not a good idea
+use Ogre::AnimableObject;
 use Ogre::AnimableValue;
 use Ogre::Animation;
 use Ogre::AnimationState;
 use Ogre::AnimationStateSet;
+use Ogre::AnimationTrack;
 use Ogre::AxisAlignedBox;
+use Ogre::AxisAlignedBoxSceneQuery;
+use Ogre::Billboard;
 use Ogre::BillboardChain;
 use Ogre::BillboardSet;
+use Ogre::Bone;
 use Ogre::Camera;
 use Ogre::ColourValue;
 use Ogre::CompositionPass;
 use Ogre::CompositionTargetPass;
 use Ogre::ConfigFile;
 use Ogre::Degree;
+use Ogre::EdgeData;
 use Ogre::Entity;
 use Ogre::Exception;
 use Ogre::Frustum;
+use Ogre::GpuProgram;
 use Ogre::GpuProgramParameters;
 use Ogre::HardwareBuffer;
 use Ogre::HardwareBufferManager;
 use Ogre::HardwareIndexBuffer;
+use Ogre::HardwarePixelBuffer;
+use Ogre::HardwareVertexBuffer;
 use Ogre::Image;
+use Ogre::IndexData;
 use Ogre::InstancedGeometry::InstancedObject;
 use Ogre::InstancedGeometry;
+use Ogre::IntersectionSceneQuery;
+use Ogre::KeyFrame;
 use Ogre::Light;
 use Ogre::LogManager;
 use Ogre::ManualObject;
+use Ogre::ManualResourceLoader;
 use Ogre::MaterialManager;
 use Ogre::Math;
 use Ogre::Matrix3;
+use Ogre::Matrix4;
+use Ogre::Mesh;
 use Ogre::MeshManager;
 use Ogre::MeshPtr;
 use Ogre::MovableObject;
+use Ogre::MultiRenderTarget;
 use Ogre::Node;
+use Ogre::NodeAnimationTrack;
+use Ogre::NumericAnimationTrack;
 use Ogre::Overlay;
 use Ogre::OverlayContainer;
 use Ogre::OverlayElement;
 use Ogre::OverlayManager;
 use Ogre::Particle;
+use Ogre::ParticleAffector;
+use Ogre::ParticleEmitter;
 use Ogre::ParticleSystem;
+use Ogre::ParticleSystemRenderer;
 use Ogre::Pass;
+use Ogre::PatchMesh;
 use Ogre::PatchSurface;
 use Ogre::Plane;
+use Ogre::PlaneBoundedVolumeListSceneQuery;
+use Ogre::Pose;
 use Ogre::ProgressiveMesh;
 use Ogre::Quaternion;
 use Ogre::QueuedRenderableCollection;
 use Ogre::Radian;
+use Ogre::Ray;
+use Ogre::RaySceneQuery;
+use Ogre::RegionSceneQuery;
 use Ogre::RenderOperation;
+use Ogre::RenderSystem;
+use Ogre::RenderSystemCapabilities;
 use Ogre::RenderTarget;
+use Ogre::RenderTexture;
 use Ogre::RenderWindow;
 use Ogre::Renderable;
 use Ogre::Resource;
 use Ogre::ResourceGroupManager;
+use Ogre::ResourceManager;
 use Ogre::RibbonTrail;
 use Ogre::Root;
 use Ogre::SceneManager;
 use Ogre::SceneNode;
 use Ogre::SceneQuery;
+use Ogre::ScriptLoader;
 use Ogre::Serializer;
+use Ogre::ShadowCaster;
+use Ogre::Skeleton;
+use Ogre::SkeletonInstance;
+use Ogre::Sphere;
+use Ogre::SphereSceneQuery;
 use Ogre::StaticGeometry;
 use Ogre::StringInterface;
 use Ogre::SubEntity;
+use Ogre::SubMesh;
+use Ogre::TagPoint;
 use Ogre::TextureManager;
 use Ogre::TextureUnitState;
+use Ogre::TimeIndex;
+use Ogre::TransformKeyFrame;
+use Ogre::Vector2;
 use Ogre::Vector3;
+use Ogre::Vector4;
 use Ogre::VertexAnimationTrack;
 use Ogre::VertexCacheProfiler;
+use Ogre::VertexBufferBinding;
+use Ogre::VertexData;
+use Ogre::VertexDeclaration;
+use Ogre::VertexElement;
 use Ogre::Viewport;
 use Ogre::WindowEventUtilities;
 
